@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 from cmsplugin_cascade.plugin_base import CascadePluginBase
-from cmsplugin_cascade.cms_plugins import framework
 
 
 class BootstrapPluginBase(CascadePluginBase):
-    module = framework == 'angular_bootstrap3' and 'Angular Bootstrap' or 'Bootstrap'
+    module = 'Bootstrap'
     require_parent = True
     allow_children = True
